from __init__ import __version__ # import current version
data = {
    "Version": __version__,
    "Module": {
        "Name": "PyTools",
        "Type": "Module",
        "Language": "Python",
        "Alias": "PyT"
    },
    "CreatedBy": "KareemTheBest",
    "PyPi": "kareemthebest@pypi.org"
}
import __init__ as pytools
